/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.loader;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jboss.cache.Node;
import org.jboss.cache.TreeCache;

/**
 * Unit test for checking interaction between cache loader and marshalled 
 * regions. 
 * 
 * @author <a href="mailto:galder.zamarreno@jboss.com">Galder Zamarreno</a>
 */
public class MarshalledCacheLoaderTest extends AbstractCacheLoaderTestBase
{
   private static final Log log = LogFactory.getLog(MarshalledCacheLoaderTest.class);
   
   private TreeCache cache;

   protected void setUp() throws Exception 
   {
      super.setUp();
      
      cache=new TreeCache();
      cache.setCacheMode("LOCAL");
      cache.setTransactionManagerLookupClass("org.jboss.cache.DummyTransactionManagerLookup");
      cache.setCacheLoaderConfiguration(getSingleCacheLoaderConfig("", DummyInMemoryCacheLoader.class.getName(), "", false, false, false));
      cache.setUseRegionBasedMarshalling(true);
      cache.setInactiveOnStartup(true);
      cache.startService();
   }
   
   protected void tearDown() throws Exception
   {
      super.tearDown();
      
      cache.remove("/");
      cache.stopService();
      cache.destroyService();
   }

   public void testLoadNodesAtRootOfRegion() throws Exception
   {
      String rootRegionName = "/myregion";
      String fqn = rootRegionName + "/here";
      
      cache.registerClassLoader(rootRegionName, Thread.currentThread().getContextClassLoader());
      cache.activateRegion(rootRegionName);
      cache.put(rootRegionName, "a key", "a value");
      cache.put(fqn, "another key", "another value");
      
      cache.inactivateRegion(rootRegionName);
      cache.unregisterClassLoader(rootRegionName);

      cache.stopService();
      cache.destroyService();    
      
      cache.startService();

      cache.registerClassLoader(rootRegionName, Thread.currentThread().getContextClassLoader());
      cache.activateRegion(rootRegionName);
      
      Node rootRegionNode = cache.get(rootRegionName);
      Node fqnNode = cache.get(fqn);
      assertNotNull(rootRegionNode);
      assertNotNull(fqnNode);
      
      assertEquals(fqnNode.get("another key"), "another value");
      assertEquals(rootRegionNode.get("a key"), "a value");
   }
   
}
